require 'spec_helper'
require 'shortcodes'

describe Shortcodes::WordpressShortcodes do
  subject(:shortcodes) { Shortcodes::WordpressShortcodes.new }

  describe '#process' do
    it 'executes a simple shortcode' do
      shortcodes.add_shortcode('foo'){ 'foo!' }
      shortcodes.process('A [foo]').should == 'A foo!'
    end

    it 'executes a wrapping shortcode and passes contents' do
      shortcodes.add_shortcode('foo'){ |attr, content| "foo#{content}!" }
      shortcodes.process('A [foo]bar[/foo] Totally').should == 'A foobar! Totally'
    end

    it 'executes a shortcode with attributes' do
      shortcodes.add_shortcode('foo'){ |attr| "foo to the #{attr['adjective']}, #{attr['noun']}!"}
      shortcodes.process('[foo noun="fox" adjective="owlish"]').should == 'foo to the owlish, fox!'
    end

    it 'executes a shortcode with attributes and content' do
      shortcodes.add_shortcode('foo'){ |attr, content| "#{content} to the #{attr['adjective']}, #{attr['noun']}!"}
      shortcodes.process('[foo noun="fox" adjective="owlish"]Greetings[/foo]').should == 'Greetings to the owlish, fox!'
    end

    it 'executes multiple shortcodes in a string' do
      shortcodes.add_shortcode('banana'){ "Bananas, yum!" }
      shortcodes.add_shortcode('pizza'){ "Pizza, yum!" }
      shortcodes.process('[banana] [pizza] [banana]').should == 'Bananas, yum! Pizza, yum! Bananas, yum!'
    end
  end
end
